@@ -13,7 +13,7 @@ use std::io::{self, BufRead, IoSlice, IoSliceMut, Read, Write};
 #[cfg(not(windows))]
 use {
     io_lifetimes::{AsFd, BorrowedFd},
-    unsafe_io::os::posish::{AsRawFd, RawFd},
+    unsafe_io::os::rsix::{AsRawFd, RawFd},
 };
 #[cfg(windows)]
 use {
